Split out isrg from ssr and reorient build graph to make interpreter build 2x faster (#2969)

* split out isrg and core-types to speed up interpreter build
This commit is contained in:
Jonathan Kelley authored and GitHub committed 2024-09-16 16:49:06 -07:00
1 parent f0d814fede
commit 143ad749ea
28 files changed
+197 -231

No files matched your search

+2 -1
View File
@@ -24,6 +24,7 @@ serde = { version = "1.0", features = ["derive"], optional = true }
rustc-hash = { workspace = true, optional = true }
dioxus-core = { workspace = true, optional = true }
dioxus-core-types = { workspace = true, optional = true }
dioxus-html = { workspace = true, optional = true }
[build-dependencies]
@@ -41,5 +42,5 @@ webonly = [
"dep:web-sys",
"sledgehammer_bindgen/web",
]
binary-protocol = ["sledgehammer", "dep:dioxus-core", "dep:dioxus-html"]
binary-protocol = ["sledgehammer", "dep:dioxus-core", "dep:dioxus-core-types", "dep:dioxus-html"]
minimal_bindings = []
@@ -1,6 +1,6 @@
use crate::unified_bindings::Interpreter as Channel;
use dioxus_core::{Template, TemplateAttribute, TemplateNode, WriteMutations};
use dioxus_html::event_bubbles;
use dioxus_core_types::event_bubbles;
use rustc_hash::FxHashMap;
/// The state needed to apply mutations to a channel. This state should be kept across all mutations for the app